EasyExtend.util.hexobject.Bin

Package EasyExtend :: Package util :: Module hexobject :: Class Bin |
[hide private]
[frames] | no frames]

# Class Bin

    object --+
             |
           int --+
                 |
                Bin

Instance Methods | [hide private]
__init__(self, data) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
num(self) |
__repr__(self) repr(x) |
Inherited from `int`: `__abs__`, `__add__`, `__and__`, `__cmp__`, `__coerce__`, `__div__`, `__divmod__`, `__float__`, `__floordiv__`, `__getattribute__`, `__getnewargs__`, `__hash__`, `__hex__`, `__index__`, `__int__`, `__invert__`, `__long__`, `__lshift__`, `__mod__`, `__mul__`, `__neg__`, `__new__`, `__nonzero__`, `__oct__`, `__or__`, `__pos__`, `__pow__`, `__radd__`, `__rand__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rlshift__`, `__rmod__`, `__rmul__`, `__ror__`, `__rpow__`, `__rrshift__`, `__rshift__`, `__rsub__`, `__rtruediv__`, `__rxor__`, `__str__`, `__sub__`, `__truediv__`, `__xor__` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, data) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)